==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/lt_LT.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Dalinimasis kitame serveryje",
    "Remote share" : "Kitame serveryje pasidalinti duomenys",
    "Remote share password" : "Kitame serveryje pasidalintų duomenų slaptažodis",
    "Cancel" : "Atsisakyti",
    "Add remote share" : "Pasidalinti duomenimis kitame serveryje",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Press Ctrl-C to copy." : "Paspauskite Ctrl-C, kad nukopijuotumėte.",
    "Invalid Federated Cloud ID" : "Neteisingas Centralizuoto Serverio ID",
    "Server to server sharing is not enabled on this server" : "Dalinimasis tarp serverių yra neleidžiamas šiame serveryje",
    "Couldn't establish a federated share." : "Neįmanoma pradėti dalintis kitame serveryje.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Neįmanoma pradėti dalintis kitame serveryje. Gal jūsų slaptažodis blogas?",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Dalinimosi kitame serveryje užklausa išsiųsta. Jūs būsite informuoti, jei pasidalinimas bus sėkmingas. ",
    "Sharing %s failed, because this item is already shared with %s" : "%s bendrinimas nepavyko, kadangi šis elementas jau yra bendrinamas su %s",
    "Not allowed to create a federated share with the same user" : "Negalima dalintis su identišku naudotoju kitame serveryje",
    "File is already shared with %s" : "Failas jau yra bendrinamas su %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "\"%s\" pasidalinimas nepavyko, neįmanoma rasti %s, tikėtina, kad serveris šiuo metu nepasiekiamas arba naudoja nepatikimą sertifikatą.",
    "Could not find share" : "Nepavyko rasti bendrinamų duomenų",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Gavote galimybę peržiūrėti duomenis \"%3$s\", kuriuos pasidalino %1$s (%2$s vardu) esantis kitame serveryje",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Gavote galimybę peržiūrėti duomenis \"{share}\", kuriuos pasidalino {user} ({behalf} vardu) esantis kitame serveryje",
    "You received \"%3$s\" as a remote share from %1$s" : "Gavote galimybę peržiūrėti duomenis \"%3$s\", kuriuos pasidalino %1$s",
    "You received {share} as a remote share from {user}" : "Gavote galimybę peržiūrėti duomenis \"{share}\", kuriuos pasidalino {user}",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Pasidalinti su manimi per #Nextcloud Centralizuoto Serverio ID, toliau %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Pasidalinti su manimi per #Nextcloud Centralizuoto Serverio ID",
    "Sharing" : "Dalinamasis",
    "Federated Cloud Sharing" : "Centralizuotas Dalinimasis Serveriuose",
    "Open documentation" : "Atverti dokumentaciją",
    "Adjust how people can share between servers." : "Nustatyti taisykles, kaip naudotojai gali dalintis duomenimis tarp serverių.",
    "Allow users on this server to send shares to other servers" : "Leisti šio serverio naudotojams dalintis duomenimis su kitais serveriais",
    "Allow users on this server to receive shares from other servers" : "Leisti šio serverio naudotojams priimti kituose serveriuose dalinamus duomenis",
    "Search global and public address book for users" : "Ieškoti vartotojų globaliose ir viešose adresų knygose",
    "Allow users to publish their data to a global and public address book" : "Leisti naudotojams viešinti savo duomenis globaliose ar viešose adresų knygose",
    "Federated Cloud" : "Centralizuotas Serveris",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Galite dalintis su visais, kas naudojasi NextCloud, ownCloud ar Pydio! Tiesiog dalinimosi dialoge įrašykite jų Centralizuoto Serverio ID. Pavyzdys: person@cloud.example.com",
    "Your Federated Cloud ID:" : "Jūsų Centralizuoto Serverio ID:",
    "Share it so your friends can share files with you:" : "Pasidalinkite tam, kad jūsų draugai galėtų dalintis duomenimis su jumis:",
    "Add to your website" : "Pridėti jūsų puslapį",
    "Share with me via Nextcloud" : "Pasidalinti su manimi per NextCloud",
    "HTML Code:" : "HTML kodas:",
    "The mountpoint name contains invalid characters." : "Prijungimo taškas turi netinkamų naudoti simbolių.",
    "Not allowed to create a federated share with the owner." : "Savininkas neleidžia dalintis duomenimis su kitu serveriu.",
    "Invalid or untrusted SSL certificate" : "Neteisingas arba nepatikimas SSL liudijimas",
    "Could not authenticate to remote share, password might be wrong" : "Neįmanoma pradėti dalintis kitame serveryje. Gal jūsų slaptažodis blogas?",
    "Storage not valid" : "Saugykla netinkama naudotis",
    "Federated share added" : "Pasidalinta per kitą serverį",
    "Couldn't add remote share" : "Nepavyko peržiūrėti kitame serveryje pasidalintų duomenų",
    "Search global and public address book for users and let local users publish their data" : "Rasti globalias ar viešas adresų knygas ir leisti naudotojams viešinti savo duomenis"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/lt_LT.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Dalinimasis kitame serveryje",
    "Remote share" : "Kitame serveryje pasidalinti duomenys",
    "Remote share password" : "Kitame serveryje pasidalintų duomenų slaptažodis",
    "Cancel" : "Atsisakyti",
    "Add remote share" : "Pasidalinti duomenimis kitame serveryje",
    "Copy" : "Kopijuoti",
    "Copied!" : "Adresas nukopijuotas",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Press Ctrl-C to copy." : "Paspauskite Ctrl-C, kad nukopijuotumėte.",
    "Invalid Federated Cloud ID" : "Neteisingas Centralizuoto Serverio ID",
    "Server to server sharing is not enabled on this server" : "Dalinimasis tarp serverių yra neleidžiamas šiame serveryje",
    "Couldn't establish a federated share." : "Neįmanoma pradėti dalintis kitame serveryje.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Neįmanoma pradėti dalintis kitame serveryje. Gal jūsų slaptažodis blogas?",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Dalinimosi kitame serveryje užklausa išsiųsta. Jūs būsite informuoti, jei pasidalinimas bus sėkmingas. ",
    "Not allowed to create a federated share with the same user" : "Negalima dalintis su identišku naudotoju kitame serveryje",
    "File is already shared with %s" : "Failas jau yra bendrinamas su %s",
    "Could not find share" : "Nepavyko rasti bendrinamų duomenų",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Gavote galimybę peržiūrėti duomenis \"%3$s\", kuriuos pasidalino %1$s (%2$s vardu) esantis kitame serveryje",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Gavote galimybę peržiūrėti duomenis \"{share}\", kuriuos pasidalino {user} ({behalf} vardu) esantis kitame serveryje",
    "You received \"%3$s\" as a remote share from %1$s" : "Gavote galimybę peržiūrėti duomenis \"%3$s\", kuriuos pasidalino %1$s",
    "You received {share} as a remote share from {user}" : "Gavote galimybę peržiūrėti duomenis \"{share}\", kuriuos pasidalino {user}",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Pasidalinti su manimi per #Nextcloud Centralizuoto Serverio ID, toliau %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Pasidalinti su manimi per #Nextcloud Centralizuoto Serverio ID",
    "Sharing" : "Duomenų keitimasis",
    "Federated Cloud Sharing" : "Duomenų keitimasis tarp saugyklų",
    "Open documentation" : "Detalesnė informacija",
    "Adjust how people can share between servers." : "Nustatyti taisykles, kaip naudotojai gali keistis duomenimis tarp saugyklų",
    "Allow users on this server to send shares to other servers" : "Leisti naudotojams keistis duomenimis su kitomis saugyklomis",
    "Allow users on this server to receive shares from other servers" : "Leisti naudotojams priimti duomenis iš kitų saugyklų",
    "Search global and public address book for users" : "Leisti ieškoti adresatų kitose saugyklose",
    "Allow users to publish their data to a global and public address book" : "Leisti naudotojams publikuoti savo kontaktus kitose saugyklose",
    "Federated Cloud" : "Duomenų saugyklos informacija",
    "You can share with anyone who uses Nextcloud, ownCloud or Pydio! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Duomenis galima siųsti visiems, kas naudojasi NextCloud, ownCloud ar Pydio programine įranga. Siuntimo lange įrašykite gavėjo elektroninį paštą arba saugyklos adresą.",
    "Your Federated Cloud ID:" : "Jūsų saugyklos adresas:",
    "Share it so your friends can share files with you:" : "Publikuoti asmeninės saugyklos adresą socialiniame tinkle:",
    "Add to your website" : "HTML",
    "Share with me via Nextcloud" : "Papildoma informacija",
    "HTML Code:" : "Programinis kodas:",
    "The mountpoint name contains invalid characters." : "Prijungimo taškas turi netinkamų naudoti simbolių.",
    "Not allowed to create a federated share with the owner." : "Savininkas neleidžia dalintis duomenimis su kitu serveriu.",
    "Invalid or untrusted SSL certificate" : "Neteisingas arba nepatikimas SSL liudijimas",
    "Could not authenticate to remote share, password might be wrong" : "Neįmanoma pradėti dalintis kitame serveryje. Gal jūsų slaptažodis blogas?",
    "Storage not valid" : "Saugykla netinkama naudotis",
    "Federated share added" : "Pasidalinta per kitą serverį",
    "Couldn't add remote share" : "Nepavyko peržiūrėti kitame serveryje pasidalintų duomenų",
    "Sharing %s failed, because this item is already shared with %s" : "%s bendrinimas nepavyko, kadangi šis elementas jau yra bendrinamas su %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "\"%s\" pasidalinimas nepavyko, neįmanoma rasti %s, tikėtina, kad serveris šiuo metu nepasiekiamas arba naudoja nepatikimą sertifikatą.",
    "Search global and public address book for users and let local users publish their data" : "Rasti globalias ar viešas adresų knygas ir leisti naudotojams viešinti savo duomenis"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
